@@ -90,7 +90,7 @@ void cover_dump(CoverList* cover, FILE* fp) {
    * We output the cover data as elements in a JSON hash
    * that must be opened / closed OUTSIDE this routine.
    */
-  fprintf(fp, "\"files\":{");
+  fprintf(fp, "\"files\":\n{");
   for (i = 0 ; i < cover->size; i++) {
     int j = 0;
     int lcount = 0;
@@ -100,9 +100,9 @@ void cover_dump(CoverList* cover, FILE* fp) {
     }
 
     if (ncount++) {
-      fprintf(fp, ",");
+      fprintf(fp, ",\n");
     }
-    fprintf(fp, "\"%s\":{",
+    fprintf(fp, "\"%s\":[",
             node->file);
     for (j = 0; j < node->bmax; ++j) {
       if (BIT_IS_ON(node->lines, j)) {
@@ -110,10 +110,10 @@ void cover_dump(CoverList* cover, FILE* fp) {
         if (lcount++) {
           fprintf(fp, ",");
         }
-        fprintf(fp, "\"%d\":%d", j+1, 1);
+        fprintf(fp, "%d", j+1);
       }
     }
-    fprintf(fp, "}");
+    fprintf(fp, "]");
   }
   fprintf(fp, "}");
 }
